==> spip_4.1.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Geen bericht in het forum',

	// B
	'bouton_radio_articles_futurs' => 'alleen voor toekomstige artikelen (geen bewerking op de database).',
	'bouton_radio_articles_tous' => 'voor alle artikelen zonder uitzondering.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'voor alle artikelen, behalve deze waarvan het forum is gedesactiveerd.',
	'bouton_radio_enregistrement_obligatoire' => 'Registratie verplicht (om bijdragen te kunnen
  posten, dienen gebruikers zich eerst in te schrijven en hun e-mailadres aan te leveren).',
	'bouton_radio_moderation_priori' => 'Vooraf modereren (de bijdragen worden pas gepubliceerd na goedkeuring door een van de beheerders).',
	'bouton_radio_modere_abonnement' => 'op aanvraag',
	'bouton_radio_modere_posteriori' => 'achteraf modereren',
	'bouton_radio_modere_priori' => 'vooraf modereren',
	'bouton_radio_publication_immediate' => 'Onmiddellijke publicatie van berichten
 (bijdragen worden zichtbaar zodra ze verstuurd worden; beheerders kunnen nadien nog steeds
 berichten schrappen).',

	// D
	'documents_interdits_forum' => 'Verboden documenten in het forum',

	// E
	'erreur_enregistrement_message' => 'Wegens technische problemen kon je bericht niet opgeslaagd worden',
	'extensions_autorisees' => 'Toegestane extensies:',
	'extensions_autorisees_toutes' => 'alles',

	// F
	'form_pet_message_commentaire' => 'Een bericht, een commentaar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Je hebt geen toegang meer tot deze forums.',
	'forum_attention_dix_caracteres' => '<b>Opgelet!</b> Je bericht moet minstens 10 tekens bevatten.',
	'forum_attention_message_non_poste' => '<b>Opgelet!</b> Je hebt je bericht niet gepost!',
	'forum_attention_nb_caracteres_mini' => '<b>Opgelet!</b> Je bericht moet tenminste @min@ tekens bevatten.',
	'forum_attention_trois_caracteres' => '<b>Opgelet!</b> je bericht moet minstens 3 tekens bevatten.',
	'forum_attention_trop_caracteres' => '<b>Opgelet!</b> Je bericht is te lang (@compte@ tekens): om opgeslagen te worden, mag het niet meer dan @max@ tekens bevatten.',
	'forum_avez_selectionne' => 'Je hebt gekozen:',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>hier</a> om door te gaan.',
	'forum_envoyer' => 'Verzenden',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Dit forum wordt vooraf gemodereerd: je bijdrage zal pas verschijnen nadat een beheerder van de website het heeft goedgekeurd.',
	'forum_lien_hyper' => 'webverwijzing',
	'forum_message' => 'Je bericht',
	'forum_message_definitif' => 'Definitief bericht: versturen',
	'forum_message_trop_long' => 'Je bericht is te lang. De maximale lengte is 20.000 tekens.',
	'forum_ne_repondez_pas' => 'Niet reageren op deze mail, maar op het forum op het volgende adres:',
	'forum_page_url' => '(Als je bericht naar een artikel op het web verwijst of naar een pagina die meer informatie bevat, kun je hier de titel en de URL van deze webverwijzing invoeren.)',
	'forum_permalink' => 'Permanente link naar het commentaar',
	'forum_poste_par' => 'bericht gepost @parauteur@ als vervolg op artikel «@titre@».',
	'forum_poste_par_court' => 'Bericht gepost @parauteur@.',
	'forum_poste_par_generique' => 'Bericht gepost @parauteur@ (@objet@ «@titre@»).',
	'forum_qui_etes_vous' => 'Wie ben je?',
	'forum_saisie_texte_info' => 'In dit formulier mag je deze codes gebruiken: <code>[-&gt;url] {{vetschrift}} {cursief} &lt;quote&gt; &lt;code&gt;</code> en de HTML codes: <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Om een paragraaf aan te maken voeg je gewoon lege regels toe.',
	'forum_texte' => 'Tekst van je bericht',
	'forum_titre' => 'Titel',
	'forum_url' => 'Je website',
	'forum_valider' => 'Keuze bevestigen',
	'forum_voir_avant' => 'Bericht bekijken alvorens te posten',
	'forum_votre_email' => 'Je e-mailadres',
	'forum_votre_nom' => 'Je naam',
	'forum_vous_enregistrer' => 'Om deel te nemen aan
  dit forum, dien je je eerst te registreren. Vul
  hieronder de inloggevens in die je werden toegezonden.
  Als je nog niet geregistreerd bent, dien je je ',
	'forum_vous_inscrire' => 'in te schrijven.',

	// I
	'icone_bruler_message' => 'Als SPAM rapporteren',
	'icone_bruler_messages' => 'Als SPAM rapporteren',
	'icone_legitimer_message' => 'Als geldig rapporteren',
	'icone_poster_message' => 'Een bericht versturen',
	'icone_suivi_forum' => 'Opvolging van het publieke forum: @nb_forums@ bijdrage(n)',
	'icone_suivi_forums' => 'Forums opvolgen/beheren',
	'icone_supprimer_message' => 'Dit bericht wissen',
	'icone_supprimer_messages' => 'Die boodschappen verwijderen',
	'icone_valider_message' => 'Bericht goedkeuren',
	'icone_valider_messages' => 'Deze berichten goedkeuren',
	'icone_valider_repondre_message' => 'Boodschap valideren en beantwoorden',
	'info_1_message_forum' => '1 boodschap in het forum',
	'info_activer_forum_public' => 'Om de openbare forums te activeren, dien je een standaardinstelling
 voor het modereren te kiezen:',
	'info_appliquer_choix_moderation' => 'Pas deze moderatievorm toe:',
	'info_config_forums_prive' => 'In het privé gedeelte van de site kun je verschillende soorten forums activeren:',
	'info_config_forums_prive_admin' => 'Een forum dat voor de beheerders van de site is gereserveerd:',
	'info_config_forums_prive_global' => 'Een globaal forum, open voor alle redacteuren:',
	'info_config_forums_prive_objets' => 'Een forum onder elk artikel, elke nieuwsflits, gerefereerde site, enz.:',
	'info_desactiver_forum_public' => 'Het gebruik van de publieke forums deactiveren.
De publieke forums kunnen per artikel toegestaan worden. Ze worden niet toegestaan op rubrieken en nieuwsberichten, enz.',
	'info_envoi_forum' => 'Versturen van de forumbijdragen aan de auteurs van de artikelen',
	'info_fonctionnement_forum' => 'Werking van het forum:',
	'info_forcer_previsualisation_court' => 'Forceer een vooruitblik',
	'info_forcer_previsualisation_long' => 'Forceer een vooruitblik voordat een bericht verzonden wordt',
	'info_forums_liees_mot' => 'De forumboodschappen met dit trefwoord',
	'info_gauche_suivi_forum_2' => 'De pagina <i>Forums opvolgen/beheren</i> is beheerfunctie van de site (en niet een discussieruimte). Zij geeft alle bijdragen aan de forums van de site weer, zowel van de openbare site als van het privé gedeelte.', # A revoir
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'zijn',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'is',
	'info_liens_syndiques_7' => 'nog niet goedgekeurd',
	'info_liens_texte' => 'Link(s) inbegrepen in de boodschap',
	'info_liens_titre' => 'Link(s) inbegrepen in het titel van de boodschap',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standaard werkwijze van de publieke forums',
	'info_nb_messages_forum' => '@nb@ boodschappen in de forums',
	'info_option_email' => 'Wanneer een bezoeker van de site een nieuw bericht in het forum opstelt dat aan een artikel is gekoppeld, kunnen de auteurs van het artikel per email over de bijdrage worden geïnformeerd. Geef voor elk soort forum aan of deze keuze moet worden toegepast.',
	'info_pas_de_forum' => 'geen forum',
	'info_question_visiteur_ajout_document_forum' => 'Als je de bezoekers documenten (afbeeldingen, geluid…) wil laten toevoegen aan hun forumbijdrage, moet je hieronder de lijst van de toegelaten extensies aangeven (bv: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Als je alle soorten documenten wilt toestaan die door SPIP als betrouwbaar worden beschouwd, zet je een ster. Om niets toe te staan vul je niets in.',
	'info_selectionner_message' => 'Selecteer de berichten:',
	'interface_formulaire' => 'Formulier interface',
	'interface_onglets' => 'Tab interface',
	'item_activer_forum_administrateur' => 'Forum van beheerders activeren',
	'item_config_forums_prive_global' => 'Het redacteurenforum activeren',
	'item_config_forums_prive_objets' => 'Deze forums activeren',
	'item_desactiver_forum_administrateur' => 'Forum van de beheerders deactiveren',
	'item_non_config_forums_prive_global' => 'Het forum van de redacteuren deactiveren',
	'item_non_config_forums_prive_objets' => 'Deze forums deactiveren',

	// L
	'label_selectionner' => 'Selecteren: ',
	'lien_reponse_article' => 'Reageer op dit artikel',
	'lien_reponse_breve_2' => 'Reageer op deze nieuwsflits',
	'lien_reponse_message' => 'Reageer op deze bijdrage',
	'lien_reponse_rubrique' => 'Reageer op deze rubriek',
	'lien_reponse_site_reference' => 'Reageer op deze gerefereerde site',
	'lien_vider_selection' => 'Selectie leegmaken',

	// M
	'messages_aucun' => 'Geen',
	'messages_meme_auteur' => 'Alle boodschappen van deze auteur',
	'messages_meme_email' => 'Alle boodschappen van dit e-mailadres',
	'messages_meme_ip' => 'Alle boodschappen van dit IP-adres',
	'messages_off' => 'Verwijderd',
	'messages_perso' => 'Persoonlijk ',
	'messages_privadm' => 'Beheerders',
	'messages_prive' => 'Privé',
	'messages_privoff' => 'Verwijderd',
	'messages_privrac' => 'Algemene',
	'messages_prop' => 'Voorgestelde',
	'messages_publie' => 'Gepubliceerde ',
	'messages_spam' => 'SPAM',
	'messages_tous' => 'Alles',

	// O
	'onglet_messages_internes' => 'Interne berichten',
	'onglet_messages_publics' => 'Publieke berichten',
	'onglet_messages_vide' => 'Berichten zonder tekst',

	// R
	'repondre_message' => 'Op dit bericht reageren',

	// S
	'statut_off' => 'Verwijderd',
	'statut_original' => 'origineel',
	'statut_prop' => 'Voorgesteld',
	'statut_publie' => 'Gepubliceerd',
	'statut_spam' => 'SPAM',

	// T
	'text_article_propose_publication_forum' => 'Geef je advies over dit artikel via het gekoppelde forum (onderaan de bladzijde).',
	'texte_en_cours_validation' => 'Deze inhoud is in afwachting van validatie',
	'texte_en_cours_validation_forum' => 'Aarzel niet om advies te geven via het gekoppelde forum.',
	'texte_messages_publics' => 'Openbare berichten op:',
	'titre_cadre_forum_administrateur' => 'Privé-forum voor beheerders',
	'titre_cadre_forum_interne' => 'Intern forum',
	'titre_config_forums_prive' => 'Forums van het privé gedeelte',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Opvolgen van de forums',
	'titre_page_forum_suivi' => 'Forumopvolging',
	'titre_selection_action' => 'Selectie',
	'tout_voir' => 'Alles bekijken',

	// V
	'voir_messages_objet' => 'berichten bekijken'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Geen bericht in het forum',

	// B
	'bouton_radio_articles_futurs' => 'alleen voor toekomstige artikelen (geen bewerking op de database).',
	'bouton_radio_articles_tous' => 'voor alle artikelen zonder uitzondering.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'voor alle artikelen, behalve deze waarvan het forum is gedesactiveerd.',
	'bouton_radio_enregistrement_obligatoire' => 'Registratie verplicht (om bijdragen te kunnen
  posten, dienen gebruikers zich eerst in te schrijven en hun e-mailadres aan te leveren).',
	'bouton_radio_moderation_priori' => 'Vooraf modereren (de bijdragen worden pas gepubliceerd na goedkeuring door een van de beheerders).',
	'bouton_radio_modere_abonnement' => 'op aanvraag',
	'bouton_radio_modere_posteriori' => 'achteraf modereren',
	'bouton_radio_modere_priori' => 'vooraf modereren',
	'bouton_radio_publication_immediate' => 'Onmiddellijke publicatie van berichten
 (bijdragen worden zichtbaar zodra ze verstuurd worden; beheerders kunnen nadien nog steeds
 berichten schrappen).',

	// D
	'documents_interdits_forum' => 'Verboden documenten in het forum',

	// E
	'erreur_enregistrement_message' => 'Wegens technische problemen kon je bericht niet opgeslaagd worden',
	'extensions_autorisees' => 'Toegestane extensies:',
	'extensions_autorisees_toutes' => 'alles',

	// F
	'form_pet_message_commentaire' => 'Een bericht, een commentaar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Je hebt geen toegang meer tot deze forums.',
	'forum_attention_dix_caracteres' => '<b>Opgelet!</b> Je bericht moet minstens 10 tekens bevatten.',
	'forum_attention_message_non_poste' => '<b>Opgelet!</b> Je hebt je bericht niet gepost!',
	'forum_attention_nb_caracteres_mini' => '<b>Opgelet!</b> Je bericht moet tenminste @min@ tekens bevatten.',
	'forum_attention_trois_caracteres' => '<b>Opgelet!</b> je bericht moet minstens 3 tekens bevatten.',
	'forum_attention_trop_caracteres' => '<b>Opgelet!</b> Je bericht is te lang (@compte@ tekens): om opgeslagen te worden, mag het niet meer dan @max@ tekens bevatten.',
	'forum_avez_selectionne' => 'Je hebt gekozen:',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>hier</a> om door te gaan.',
	'forum_envoyer' => 'Verzenden',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Dit forum wordt vooraf gemodereerd: je bijdrage zal pas verschijnen nadat een beheerder van de website het heeft goedgekeurd.',
	'forum_lien_hyper' => 'webverwijzing',
	'forum_message' => 'Je bericht',
	'forum_message_definitif' => 'Definitief bericht: versturen',
	'forum_message_trop_long' => 'Je bericht is te lang. De maximale lengte is 20.000 tekens.',
	'forum_ne_repondez_pas' => 'Niet reageren op deze mail, maar op het forum op het volgende adres:',
	'forum_page_url' => '(Als je bericht naar een artikel op het web verwijst of naar een pagina die meer informatie bevat, kun je hier de titel en de URL van deze webverwijzing invoeren.)',
	'forum_permalink' => 'Permanente link naar het commentaar',
	'forum_poste_par' => 'bericht gepost @parauteur@ als vervolg op artikel «@titre@».',
	'forum_poste_par_court' => 'Bericht gepost @parauteur@.',
	'forum_poste_par_generique' => 'Bericht gepost @parauteur@ (@objet@ «@titre@»).',
	'forum_qui_etes_vous' => 'Wie ben je?',
	'forum_saisie_texte_info' => 'In dit formulier mag je deze codes gebruiken: <code>[-&gt;url] {{vetschrift}} {cursief} &lt;quote&gt; &lt;code&gt;</code> en de HTML codes: <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Om een paragraaf aan te maken voeg je gewoon lege regels toe.',
	'forum_texte' => 'Tekst van je bericht',
	'forum_titre' => 'Titel',
	'forum_url' => 'Je website',
	'forum_valider' => 'Keuze bevestigen',
	'forum_voir_avant' => 'Bericht bekijken alvorens te posten',
	'forum_votre_email' => 'Je e-mailadres',
	'forum_votre_nom' => 'Je naam',
	'forum_vous_enregistrer' => 'Om deel te nemen aan
  dit forum, dien je je eerst te registreren. Vul
  hieronder de inloggevens in die je werden toegezonden.
  Als je nog niet geregistreerd bent, dien je je ',
	'forum_vous_inscrire' => 'in te schrijven.',

	// I
	'icone_bruler_message' => 'Als SPAM rapporteren',
	'icone_bruler_messages' => 'Als SPAM rapporteren',
	'icone_legitimer_message' => 'Als geldig rapporteren',
	'icone_poster_message' => 'Een bericht versturen',
	'icone_suivi_forum' => 'Opvolging van het publieke forum: @nb_forums@ bijdrage(n)',
	'icone_suivi_forums' => 'Forums opvolgen/beheren',
	'icone_supprimer_message' => 'Dit bericht wissen',
	'icone_supprimer_messages' => 'Die boodschappen verwijderen',
	'icone_valider_message' => 'Bericht goedkeuren',
	'icone_valider_messages' => 'Deze berichten goedkeuren',
	'icone_valider_repondre_message' => 'Boodschap valideren en beantwoorden',
	'info_1_message_forum' => '1 boodschap in het forum',
	'info_activer_forum_public' => 'Om de openbare forums te activeren, dien je een standaardinstelling
 voor het modereren te kiezen:',
	'info_appliquer_choix_moderation' => 'Pas deze moderatievorm toe:',
	'info_config_forums_prive' => 'In het privé gedeelte van de site kun je verschillende soorten forums activeren:',
	'info_config_forums_prive_admin' => 'Een forum dat voor de beheerders van de site is gereserveerd:',
	'info_config_forums_prive_global' => 'Een globaal forum, open voor alle redacteuren:',
	'info_config_forums_prive_objets' => 'Een forum onder elk artikel, elke nieuwsflits, gerefereerde site, enz.:',
	'info_desactiver_forum_public' => 'Het gebruik van de publieke forums deactiveren.
De publieke forums kunnen per artikel toegestaan worden. Ze worden niet toegestaan op rubrieken en nieuwsberichten, enz.',
	'info_envoi_forum' => 'Versturen van de forumbijdragen aan de auteurs van de artikelen',
	'info_fonctionnement_forum' => 'Werking van het forum:',
	'info_forcer_previsualisation_court' => 'Forceer een vooruitblik',
	'info_forcer_previsualisation_long' => 'Forceer een vooruitblik voordat een bericht verzonden wordt',
	'info_forums_liees_mot' => 'De forumboodschappen met dit trefwoord',
	'info_gauche_suivi_forum_2' => 'De pagina <i>Forums opvolgen/beheren</i> is beheerfunctie van de site (en niet een discussieruimte). Zij geeft alle bijdragen aan de forums van de site weer, zowel van de openbare site als van het privé gedeelte.', # A revoir
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'zijn',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'is',
	'info_liens_syndiques_7' => 'nog niet goedgekeurd',
	'info_liens_texte' => 'Link(s) inbegrepen in de boodschap',
	'info_liens_titre' => 'Link(s) inbegrepen in het titel van de boodschap',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standaard werkwijze van de publieke forums',
	'info_nb_messages_forum' => '@nb@ boodschappen in de forums',
	'info_option_email' => 'Wanneer een bezoeker van de site een nieuw bericht in het forum opstelt dat aan een artikel is gekoppeld, kunnen de auteurs van het artikel per email over de bijdrage worden geïnformeerd. Geef voor elk soort forum aan of deze keuze moet worden toegepast.',
	'info_pas_de_forum' => 'geen forum',
	'info_question_visiteur_ajout_document_forum' => 'Als je de bezoekers documenten (afbeeldingen, geluid…) wil laten toevoegen aan hun forumbijdrage, moet je hieronder de lijst van de toegelaten extensies aangeven (bv: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Als je alle soorten documenten wilt toestaan die door SPIP als betrouwbaar worden beschouwd, zet je een ster. Om niets toe te staan vul je niets in.',
	'info_selectionner_message' => 'Selecteer de berichten:',
	'interface_formulaire' => 'Formulier interface',
	'interface_onglets' => 'Tab interface',
	'item_activer_forum_administrateur' => 'Forum van beheerders activeren',
	'item_config_forums_prive_global' => 'Het redacteurenforum activeren',
	'item_config_forums_prive_objets' => 'Deze forums activeren',
	'item_desactiver_forum_administrateur' => 'Forum van de beheerders deactiveren',
	'item_non_config_forums_prive_global' => 'Het forum van de redacteuren deactiveren',
	'item_non_config_forums_prive_objets' => 'Deze forums deactiveren',

	// L
	'label_selectionner' => 'Selecteren: ',
	'lien_reponse_article' => 'Reageer op dit artikel',
	'lien_reponse_breve_2' => 'Reageer op deze nieuwsflits',
	'lien_reponse_message' => 'Reageer op deze bijdrage',
	'lien_reponse_rubrique' => 'Reageer op deze rubriek',
	'lien_reponse_site_reference' => 'Reageer op deze gerefereerde site',
	'lien_vider_selection' => 'Selectie leegmaken',

	// M
	'messages_aucun' => 'Geen',
	'messages_meme_auteur' => 'Alle boodschappen van deze auteur',
	'messages_meme_email' => 'Alle boodschappen van dit e-mailadres',
	'messages_meme_ip' => 'Alle boodschappen van dit IP-adres',
	'messages_off' => 'Verwijderd',
	'messages_perso' => 'Persoonlijk ',
	'messages_privadm' => 'Beheerders',
	'messages_prive' => 'Privé',
	'messages_privoff' => 'Verwijderd',
	'messages_privrac' => 'Algemene',
	'messages_prop' => 'Voorgestelde',
	'messages_publie' => 'Gepubliceerde ',
	'messages_spam' => 'SPAM',
	'messages_tous' => 'Alles',

	// O
	'onglet_messages_internes' => 'Interne berichten',
	'onglet_messages_publics' => 'Publieke berichten',
	'onglet_messages_vide' => 'Berichten zonder tekst',

	// R
	'repondre_message' => 'Op dit bericht reageren',

	// S
	'statut_off' => 'Verwijderd',
	'statut_original' => 'origineel',
	'statut_prop' => 'Voorgesteld',
	'statut_publie' => 'Gepubliceerd',
	'statut_spam' => 'SPAM',

	// T
	'text_article_propose_publication_forum' => 'Geef je advies over dit artikel via het gekoppelde forum (onderaan de bladzijde).',
	'texte_en_cours_validation' => 'Deze inhoud is in afwachting van validatie',
	'texte_en_cours_validation_forum' => 'Aarzel niet om advies te geven via het gekoppelde forum.',
	'texte_messages_publics' => 'Openbare berichten op:',
	'titre_cadre_forum_administrateur' => 'Privé-forum voor beheerders',
	'titre_cadre_forum_interne' => 'Intern forum',
	'titre_config_forums_prive' => 'Forums van het privé gedeelte',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Opvolgen van de forums',
	'titre_page_forum_suivi' => 'Forumopvolging',
	'titre_selection_action' => 'Selectie',
	'tout_voir' => 'Alles bekijken',

	// V
	'voir_messages_objet' => 'berichten bekijken',
];
